diff --git a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/set03/set03-Isengard-errata.hjson b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/set03/set03-Isengard-errata.hjson
index 44441b361..df0a33c51 100644
--- a/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/set03/set03-Isengard-errata.hjson
+++ b/gemp-lotr/gemp-lotr-cards/src/main/resources/cards/unofficial/pc/errata/set03/set03-Isengard-errata.hjson
@@ -615,7 +615,10 @@
strength: 6
vitality: 2
site: 5
- keywords: Damage+1
+ keywords: [
+ Tracker
+ Damage+1
+ ]
effects: [
{
type: modifier
@@ -663,7 +666,7 @@
}
}
]
- gametext: Damage +1.
While an ally is in the dead pile, this minion is strength +3 and fierce.
Each time an ally exerts, you may spot another [isengard] card and exert this minion to wound that ally.
+ gametext: Tracker. Damage +1.
While an ally is in the dead pile, this minion is strength +3 and fierce.
Each time an ally exerts, you may spot another [isengard] card and exert this minion to wound that ally.
lore: "'There is no safety where Saruman's emblem is shown.'"
promotext: ""
alts: {
diff --git a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/set03/Card_03_074_ErrataTests.java b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/set03/Card_03_074_ErrataTests.java
index f57e16710..62f30b350 100644
--- a/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/set03/Card_03_074_ErrataTests.java
+++ b/gemp-lotr/gemp-lotr-server/src/test/java/com/gempukku/lotro/cards/unofficial/pc/errata/set03/Card_03_074_ErrataTests.java
@@ -43,7 +43,7 @@ public class Card_03_074_ErrataTests
* Strength: 6
* Vitality: 2
* Site Number: 5
* Game Text: Damage +1.
* While an ally is in the dead pile, this minion is strength +3 and fierce.
* Each time an ally exerts, you may spot another [isengard] card and exert this minion to wound that ally.
*/
@@ -59,6 +59,7 @@ public class Card_03_074_ErrataTests
assertEquals(Culture.ISENGARD, card.getBlueprint().getCulture());
assertEquals(CardType.MINION, card.getBlueprint().getCardType());
assertEquals(Race.URUK_HAI, card.getBlueprint().getRace());
+ assertTrue(scn.hasKeyword(card, Keyword.TRACKER));
assertTrue(scn.hasKeyword(card, Keyword.DAMAGE));
assertEquals(1, scn.GetKeywordCount(card, Keyword.DAMAGE));
assertEquals(2, card.getBlueprint().getTwilightCost());
@@ -43,7 +43,7 @@ public class Card_03_074_ErrataTests
* Vitality: 2
* Site Number: 5
- * Game Text: Damage +1.
+ * Game Text: Tracker. Damage +1.
* While an ally is in the dead pile, this minion is strength +3 and fierce.
* Each time an ally exerts, you may spot another [isengard] card and exert this minion to wound that ally.